@@ -30,7 +30,8 @@ from PyQt4.QtGui import QDialog, QDialogButtonBox, QVBoxLayout, QGridLayout, \
     QLabel, QComboBox, QLineEdit, QPushButton, QFormLayout, \
     QProgressBar, QRadioButton, QSpacerItem, QSizePolicy
 
-from kde import Sorry, Information, QuestionYesNo, KDialogButtonBox, KUser, KIcon
+from kde import Sorry, NonModalInformation, QuestionYesNo, KDialogButtonBox, KUser, KIcon, \
+    DialogIgnoringEscape
 
 from util import m18n, m18nc, logWarning, logException, socketName, english, \
     appdataDir, logInfo, logDebug, removeIfExists, which
@@ -49,7 +50,7 @@ from sound import Voice
 import intelligence
 import altint
 
-from guiutil import ListComboBox, DialogIgnoringEscape
+from guiutil import ListComboBox
 from rule import Ruleset
 
 class LoginAborted(Exception):
@@ -839,7 +840,7 @@ class HumanClient(Client):
             return answered()
         else:
             # string freeze, but we do not need the & anymore...
-            return Information(m18n("&Ready for next hand?").replace('&', ''), answered)
+            return NonModalInformation(m18n("&Ready for next hand?").replace('&', ''), answered)
 
     def ask(self, move, answers):
         """server sends move. We ask the user. answers is a list with possible answers,
@@ -1031,7 +1032,7 @@ class HumanClient(Client):
             url, name, passwd = dlg.url, dlg.username, dlg.password
             host = url.split(':')[0]
             if url == Query.localServerName:
-                return self.answered(True)
+                return answered(True)
             else:
                 msg = m18nc('USER is not known on SERVER',
                     '%1 is not known on %2, do you want to open an account?', name, host)
