@@ -24,7 +24,8 @@ from util import logError, m18n, m18nc, isAlive, logWarning
 import common
 from common import WINDS, LIGHTSOURCES, InternalParameters
 import cgitb, tempfile, webbrowser
-from twisted.internet.defer import succeed
+from twisted.internet.defer import succeed, fail
+from twisted.python.failure import Failure
 
 class MyHook(cgitb.Hook):
     """override the standard cgitb hook: invoke the browser"""
@@ -57,7 +58,7 @@ try:
 except ImportError, e:
     NOTFOUND.append('Package python-zope-interface missing: %s' % e)
 
-from kde import KMessageBox, KIcon, KAction, KApplication, KToggleFullScreenAction, \
+from kde import Sorry, QuestionYesNo, KIcon, KAction, KApplication, KToggleFullScreenAction, \
     KXmlGuiWindow, KConfigDialog, KStandardAction
 
 try:
@@ -182,7 +183,7 @@ class ConfigDialog(KConfigDialog):
         if self.rulesetSelector.save():
             KConfigDialog.accept(self)
             return
-        KMessageBox.sorry(None, m18n('Cannot save your ruleset changes.<br>' \
+        Sorry(m18n('Cannot save your ruleset changes.<br>' \
             'You probably introduced a duplicate name. <br><br >Message from database:<br><br>' \
            '<message>%1</message>', Query.dbhandle.lastError().text()))
 
@@ -434,7 +435,7 @@ class PlayField(KXmlGuiWindow):
         # see http://lists.kde.org/?l=kde-games-devel&m=120071267328984&w=2
         InternalParameters.field = self
         self.game = None
-        self.startingGame = False
+        self.__startingGame = False
         self.ignoreResizing = 1
         super(PlayField, self).__init__()
         self.background = None
@@ -556,7 +557,7 @@ class PlayField(KXmlGuiWindow):
         self.adjustView()
         self.actionScoreGame = self.__kajonggAction("scoreGame", "draw-freehand", self.scoreGame, Qt.Key_C)
         self.actionPlayGame = self.__kajonggAction("play", "arrow-right", self.playGame, Qt.Key_N)
-        self.actionAbortGame = self.__kajonggAction("abort", "dialog-close", self.abort, Qt.Key_W)
+        self.actionAbortGame = self.__kajonggAction("abort", "dialog-close", self.abortAction, Qt.Key_W)
         self.actionAbortGame.setEnabled(False)
         self.actionQuit = self.__kajonggAction("quit", "application-exit", self.quit, Qt.Key_Q)
         self.actionPlayers = self.__kajonggAction("players", "im-user", self.slotPlayers)
@@ -602,31 +603,38 @@ class PlayField(KXmlGuiWindow):
         """toggle between full screen and normal view"""
         self.actionFullscreen.setFullScreen(self, toggle)
 
-    def confirmAbort(self):
-        """optionally ask if he really wants to abort the game"""
-        if (self.game is None
-                or self.game.finished()):
-            return True
-        msg = m18n("Do you really want to abort this game?")
-        return KMessageBox.questionYesNo (None, msg) == KMessageBox.Yes
+    def abortAction(self):
+        """abort current game"""
+        try:
+            self.abort()
+        except Failure:
+            pass
 
     def abort(self):
         """abort current game"""
+        def gotAnswer(result):
+            """user answered"""
+            if result:
+                return self.abortGame()
+            else:
+                self.actionAutoPlay.setChecked(demoMode)
+                return fail(Exception('no abort'))
         if not self.game:
             self.startingGame = False
             return succeed(None)
         demoMode = self.actionAutoPlay.isChecked()
         self.actionAutoPlay.setChecked(False)
-        if not self.confirmAbort():
-            self.actionAutoPlay.setChecked(demoMode)
-            return
-        return self.abortGame()
+        if self.game.finished():
+            return self.abortGame()
+        else:
+            return QuestionYesNo(m18n("Do you really want to abort this game?"), gotAnswer)
 
     def quit(self):
         """exit the application"""
+        def doNotQuit(dummy):
+            """ignore failure to abort"""
         deferred = self.abort()
-        if deferred:
-            deferred.addCallback(Client.shutdownClients).addCallback(Client.quitProgram)
+        deferred.addCallback(Client.shutdownClients).addCallback(Client.quitProgram).addErrback(doNotQuit)
         return deferred
 
     def hideGame(self, dummyResult=None):
@@ -648,6 +656,8 @@ class PlayField(KXmlGuiWindow):
         """if a game is active, abort it"""
         self.actionAutoPlay.setChecked(False)
         self.startingGame = False
+        if self.game is None: # meanwhile somebody else might have aborted
+            return succeed(None)
         if self.game.isScoringGame():
             self.hideGame()
             return succeed(None)
@@ -798,7 +808,6 @@ class PlayField(KXmlGuiWindow):
     def playGame(self):
         """play a remote game: log into a server and show its tables"""
         self.startingGame = True
-        self.updateGUI()
         try:
             HumanClient()
         except AlreadyConnected:
@@ -806,7 +815,7 @@ class PlayField(KXmlGuiWindow):
         except LoginAborted:
             pass
         except NetworkOffline, exception:
-            KMessageBox.sorry(None, m18n('You have no network connection (error code %1).', str(exception)))
+            Sorry(m18n('You have no network connection (error code %1).', str(exception)))
 
     def adjustView(self):
         """adjust the view such that exactly the wanted things are displayed
@@ -830,6 +839,18 @@ class PlayField(KXmlGuiWindow):
         if oldRect != newRect:
             view.fitInView(scene.itemsBoundingRect(), Qt.KeepAspectRatio)
 
+    @apply
+    def startingGame(): # pylint: disable=E0202
+        """are we trying to start a game?"""
+        # pylint: disable=W0212
+        def fget(self):
+            return self.__startingGame
+        def fset(self, value):
+            if value != self.__startingGame:
+                self.__startingGame = value
+                self.updateGUI()
+        return property(**locals())
+
     @apply
     def tilesetName(): # pylint: disable=E0202
         """the name of the current tileset"""
@@ -922,10 +943,7 @@ class PlayField(KXmlGuiWindow):
         actionData = action.data().toPyObject()
         if checked:
             if isinstance(actionData, type):
-                if actionData == ChatWindow:
-                    actionData = ChatWindow.createFor(self.game.client.table)
-                else:
-                    actionData = actionData(self.game)
+                actionData = actionData(game=self.game)
                 action.setData(QVariant(actionData))
                 if isinstance(actionData, ScoringDialog):
                     self.scoringDialog = actionData
@@ -945,9 +963,10 @@ class PlayField(KXmlGuiWindow):
         """switch on / off for autoPlay"""
         if self.game:
             self.centralScene.placeFocusRect() # show/hide it
-            if checked and self.clientDialog:
-                self.clientDialog.selectButton() # select default, abort timeout
             self.game.autoPlay = checked
+            if checked and self.clientDialog:
+                self.clientDialog.proposeAction() # an illegal action might have focus
+                self.clientDialog.selectButton() # select default, abort timeout
         else:
             InternalParameters.autoPlay = checked
             if checked:
