@@ -31,8 +31,9 @@
 #include <KMessageBox>
 #include <KStatusBar>
 
-#include <KGameDifficulty>
-#include <KGameThemeSelector>
+#include <KgDifficulty>
+#include <KgThemeSelector>
+#include <KGameRenderer>
 #include <KScoreDialog>
 #include <KGameClock>
 
@@ -68,11 +69,15 @@ MainWindow::MainWindow(QWidget *parent)
     statusBar()->insertItem(QLatin1String( "" ), StatusBarIndexTime, 1);
 
     // Difficulty
-    KGameDifficulty::init(this, this, SLOT(startNewGame()));
-    KGameDifficulty::addStandardLevel(KGameDifficulty::Easy);
-    KGameDifficulty::addStandardLevel(KGameDifficulty::Medium);
-    KGameDifficulty::addStandardLevel(KGameDifficulty::Hard);
-    KGameDifficulty::addStandardLevel(KGameDifficulty::VeryHard);
+    Kg::difficulty()->addStandardLevelRange(
+        KgDifficultyLevel::Easy, KgDifficultyLevel::VeryHard
+    );
+    KgDifficultyGUI::init(this);
+    connect(Kg::difficulty(), SIGNAL(currentLevelChanged(const KgDifficultyLevel*)), SLOT(startNewGame()));
+
+    KgThemeProvider* provider = Renderer::self()->themeProvider();
+    m_selector = new KgThemeSelector(provider);
+    connect(provider, SIGNAL(currentThemeChanged(const KgTheme*)), SLOT(loadSettings()));
 
     setupActions();
 
@@ -85,16 +90,6 @@ MainWindow::MainWindow(QWidget *parent)
     m_gameClock = new KGameClock(this, KGameClock::MinSecOnly);
     connect(m_gameClock, SIGNAL(timeChanged(QString)), SLOT(updateStatusBar()));
 
-    // default values of KConfig XT don't seem to work
-    // this works around it. TODO: see why (and whether it still is true)
-    if (Settings::skill() == 0) {
-        KGameDifficulty::setLevel(KGameDifficulty::Easy);
-    } else {
-        KGameDifficulty::setLevel(
-                (KGameDifficulty::standardLevel) (Settings::skill()) );
-    }
-    kDebug() << KGameDifficulty::levelString() << Settings::skill();
-
     startNewGame();
 }
 
@@ -116,7 +111,7 @@ void MainWindow::setupActions()
     KStandardAction::configureNotifications(this,
                 SLOT(configureNotifications()), actionCollection());
 
-    KStandardAction::preferences(this, SLOT(configureSettings()),
+    KStandardAction::preferences(m_selector, SLOT(showAsDialog()),
                                  actionCollection());
 
     KAction* action = new KAction(i18n("Keyboard: Field right"), this);
@@ -155,29 +150,8 @@ void MainWindow::setupActions()
     actionCollection()->addAction( QLatin1String( "kb_lock" ), action);
 }
 
-void MainWindow::configureSettings()
-{
-    if (KConfigDialog::showDialog( QLatin1String(  "settings" ))) {
-        return;
-    }
-
-    KConfigDialog *dialog = new KConfigDialog(this, QLatin1String( "settings" ),
-                                              Settings::self());
-
-    dialog->addPage(new KGameThemeSelector( dialog, Settings::self(),
-                    KGameThemeSelector::NewStuffDisableDownload ),
-                    i18n("Theme"), QLatin1String( "games-config-theme" ));
-	dialog->setFaceType(KConfigDialog::Plain); //only one page -> no page selection necessary
-
-    connect(dialog, SIGNAL(settingsChanged(QString)), this,
-            SLOT(loadSettings()));
-    dialog->setHelp(QString(), QLatin1String( "knetwalk" ));
-    dialog->show();
-}
-
 void MainWindow::loadSettings()
 {
-    Renderer::self()->setTheme(Settings::theme());
     m_view->resetCachedContent();
     m_scene->resizeScene(m_scene->sceneRect().size());
 }
@@ -186,9 +160,7 @@ void MainWindow::showHighscores()
 {
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
     scoreDialog.addField(KScoreDialog::Custom1, i18n("Moves Penalty"), QLatin1String( "moves" ));
-    scoreDialog.addLocalizedConfigGroupNames(KGameDifficulty::localizedLevelStrings()); //Add all the translations of the group names
-    scoreDialog.setConfigGroupWeights(KGameDifficulty::levelWeights());
-    scoreDialog.setConfigGroup(KGameDifficulty::localizedLevelString());
+    scoreDialog.initFromDifficulty(Kg::difficulty());
     scoreDialog.exec();
 }
 
@@ -196,12 +168,9 @@ void MainWindow::startNewGame()
 {
     KNotification::event( QLatin1String( "startsound" ), i18n("New Game") );
 
-    KGameDifficulty::standardLevel l = KGameDifficulty::level();
-    Settings::setSkill((int) l);
+    const KgDifficultyLevel::StandardLevel l = Kg::difficultyLevel();
 
-    Settings::self()->writeConfig();
-
-    const bool isWrapped = (l == KGameDifficulty::VeryHard);
+    const bool isWrapped = (l == KgDifficultyLevel::VeryHard);
     const int size = boardSize();
     m_scene->startNewGame(size, size, (Wrapping)isWrapped);
     m_clickCount = -m_scene->fieldItem()->minimumMoves();
@@ -213,7 +182,7 @@ void MainWindow::startNewGame()
         m_pauseAction->setChecked(false);
     }
     m_pauseAction->setEnabled(true);
-    KGameDifficulty::setRunning(false);
+    Kg::difficulty()->setGameRunning(false);
 
     updateStatusBar();
 }
@@ -223,7 +192,7 @@ void MainWindow::gameOver()
     KNotification::event(QLatin1String( "winsound" ));
     m_gameClock->pause();
     m_pauseAction->setEnabled(false);
-    KGameDifficulty::setRunning(false);
+    Kg::difficulty()->setGameRunning(false);
 
     //=== calculate the score ====//
 
@@ -243,9 +212,7 @@ void MainWindow::gameOver()
     // show the new dialog and add the new score to it
     KScoreDialog scoreDialog(KScoreDialog::Name | KScoreDialog::Time, this);
     scoreDialog.addField(KScoreDialog::Custom1, i18n("Moves Penalty"), QLatin1String( "moves" ));
-    scoreDialog.addLocalizedConfigGroupNames(KGameDifficulty::localizedLevelStrings()); //Add all the translations of the group names
-    scoreDialog.setConfigGroupWeights(KGameDifficulty::levelWeights());
-    scoreDialog.setConfigGroup(KGameDifficulty::localizedLevelString());
+    scoreDialog.initFromDifficulty(Kg::difficulty());
     bool madeIt = scoreDialog.addScore(scoreInfo);
     if (!madeIt) {
         QString comment = i18np("Your score was %1, you did not make it to the high score list.",
@@ -257,7 +224,7 @@ void MainWindow::gameOver()
 
 void MainWindow::rotationPerformed()
 {
-    KGameDifficulty::setRunning(true);
+    Kg::difficulty()->setGameRunning(true);
     m_clickCount++;
     updateStatusBar();
 }
@@ -287,10 +254,10 @@ void MainWindow::configureNotifications()
 
 int MainWindow::boardSize()
 {
-    switch (KGameDifficulty::level()) {
-    case KGameDifficulty::Easy: return NoviceBoardSize;
-    case KGameDifficulty::Medium: return NormalBoardSize;
-    case KGameDifficulty::Hard: return ExpertBoardSize;
+    switch (Kg::difficultyLevel()) {
+    case KgDifficultyLevel::Easy: return NoviceBoardSize;
+    case KgDifficultyLevel::Medium: return NormalBoardSize;
+    case KgDifficultyLevel::Hard: return ExpertBoardSize;
     default: return MasterBoardSize;
     }
 }
