@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 1995 Paul Olav Tvete <paul@troll.no>
  * Copyright (C) 2000-2009 Stephan Kulow <coolo@kde.org>
- * Copyright (C) 2010 Parker Coates <parker.coates@kdemail.net>
+ * Copyright (C) 2010 Parker Coates <coates@kde.org>
  *
  * License of original code:
  * -------------------------------------------------------------------------
@@ -130,7 +130,7 @@ public:
     bool isHighlighted() const;
 
     void add( KCard * card );
-    virtual void insert( KCard * card, int index );
+    virtual void insert( int index, KCard * card );
     virtual void remove( KCard * card );
     void clear();
     void swapCards( int index1, int index2 );
